agentle.agents.exceptions
=========================

.. automodule:: agentle.agents.exceptions

   
   .. rubric:: Exceptions

   .. autosummary::
   
      SkipToolCallError
      StopAgentError
   
.. rubric:: Modules

.. autosummary::
   :toctree:
   :recursive:

   skip_tool_call_error
   stop_agent_error
